==> seb-0.0.0.tar.gz: seb-0.0.0/README.md <==
<a href="https://github.com/KennethEnevoldsen/scandinavian-embedding-benchmark"><img src="https://github.com/KennethEnevoldsen/scandinavian-embedding-benchmark/blob/main/docs/_static/logo.png?raw=true" width="120" align="right"/></a>

# Scandinavian Embedding Benchmark

[![PyPI](https://img.shields.io/pypi/v/scandinavian-embedding-benchmark.svg)][pypi status]
[![Python Version](https://img.shields.io/pypi/pyversions/scandinavian-embedding-benchmark)][pypi status]
[![documentation](https://github.com/KennethEnevoldsen/scandinavian-embedding-benchmark/actions/workflows/documentation.yml/badge.svg)][documentation]
[![Tests](https://github.com/KennethEnevoldsen/scandinavian-embedding-benchmark/actions/workflows/tests.yml/badge.svg)][tests]
[![Black](https://img.shields.io/badge/code%20style-black-000000.svg)][black]

[pypi status]: https://pypi.org/project/scandinavian-embedding-benchmark/
[documentation]: https://KennethEnevoldsen.github.io/scandinavian-embedding-benchmark/
[tests]: https://github.com/KennethEnevoldsen/scandinavian-embedding-benchmark/actions?workflow=Tests
[black]: https://github.com/psf/black


<!-- start short-description -->

A benchmark for evaluating sentence/document embeddings of Scandinavian language models.

<!-- end short-description -->

## Installation

You can install `scandinavian-embedding-benchmark` via [pip] from [PyPI]:

```bash
pip install seb
```

[pip]: https://pip.pypa.io/en/stable/installing/
[PyPI]: https://pypi.org/project/cuecy/


To see more examples, see the [documentation].

# 📖 Documentation

| Documentation         |                                                          |
| --------------------- | -------------------------------------------------------- |
| 🔧 **[Installation]**  | Installation instructions on how to install this package |
| 👩‍💻 **[Usage]**         | Introduction on how to use the package                   |
| 📖 **[Documentation]** | A minimal and developing documentation                   |


# 💬 Where to ask questions

| Type                           |                        |
| ------------------------------ | ---------------------- |
| 🚨 **Bug Reports**              | [GitHub Issue Tracker] |
| 🎁 **Feature Requests & Ideas** | [GitHub Issue Tracker] |
| 👩‍💻 **Usage Questions**          | [GitHub Discussions]   |
| 🗯 **General Discussion**       | [GitHub Discussions]   |

[Usage]: https://kennethenevoldsen.github.io/scandinavian-embedding-benchmark/getting_started/
[Documentation]: https://KennethEnevoldsen.github.io/scandinavian-embedding-benchmark/index.html
[Installation]: https://KennethEnevoldsen.github.io/scandinavian-embedding-benchmark/installation.html
[github issue tracker]: https://github.com/KennethEnevoldsen/scandinavian-embedding-benchmark/issues
[github discussions]: https://github.com/KennethEnevoldsen/scandinavian-embedding-benchmark/discussions

==> seb-0.2.3.tar.gz: seb-0.2.3/README.md <==
<a href="https://github.com/KennethEnevoldsen/scandinavian-embedding-benchmark"><img src="https://github.com/KennethEnevoldsen/scandinavian-embedding-benchmark/blob/main/docs/_static/logo.png?raw=true" width="120" align="right"/></a>

# Scandinavian Embedding Benchmark

[![PyPI](https://img.shields.io/pypi/v/seb.svg)][pypi status]
[![Python Version](https://img.shields.io/pypi/pyversions/seb)][pypi status]
[![documentation](https://github.com/KennethEnevoldsen/scandinavian-embedding-benchmark/actions/workflows/documentation.yml/badge.svg)][documentation]
[![Tests](https://github.com/KennethEnevoldsen/scandinavian-embedding-benchmark/actions/workflows/tests.yml/badge.svg)][tests]
[![Black](https://img.shields.io/badge/code%20style-black-000000.svg)][black]

[pypi status]: https://pypi.org/project/seb/
[documentation]: https://KennethEnevoldsen.github.io/scandinavian-embedding-benchmark/
[tests]: https://github.com/KennethEnevoldsen/scandinavian-embedding-benchmark/actions?workflow=Tests
[black]: https://github.com/psf/black


<!-- start short-description -->

A benchmark for evaluating sentence/document embeddings of Scandinavian language models.

<!-- end short-description -->

## Installation

You can install the Scandinavian Embedding Benchmark (`seb`) via [pip] from [PyPI]:

```bash
pip install seb
```

[pip]: https://pip.pypa.io/en/stable/installing/
[PyPI]: https://pypi.org/project/seb/


To see more examples, see the [documentation].

# 📖 Documentation

| Documentation         |                                                          |
| --------------------- | -------------------------------------------------------- |
| 🔧 **[Installation]**  | Installation instructions on how to install this package |
| 👩‍💻 **[Usage]**         | Introduction on how to use the package                   |
| 📖 **[Documentation]** | A minimal and developing documentation                   |


# 💬 Where to ask questions

| Type                           |                        |
| ------------------------------ | ---------------------- |
| 🚨 **Bug Reports**              | [GitHub Issue Tracker] |
| 🎁 **Feature Requests & Ideas** | [GitHub Issue Tracker] |
| 👩‍💻 **Usage Questions**          | [GitHub Discussions]   |
| 🗯 **General Discussion**       | [GitHub Discussions]   |

[Usage]: https://kennethenevoldsen.github.io/scandinavian-embedding-benchmark/getting_started/
[Documentation]: https://KennethEnevoldsen.github.io/scandinavian-embedding-benchmark/index.html
[Installation]: https://KennethEnevoldsen.github.io/scandinavian-embedding-benchmark/installation.html
[github issue tracker]: https://github.com/KennethEnevoldsen/scandinavian-embedding-benchmark/issues
[github discussions]: https://github.com/KennethEnevoldsen/scandinavian-embedding-benchmark/discussions
